@@ -5,11 +5,11 @@ from .webos_client import StorageSqliteDict, WebOsClient
 try:
     from .lut_tools import (
         create_dolby_vision_config,
+        generate_dolby_vision_config,
         read_cal_file,
         read_cube_file,
         unity_lut_1d,
         unity_lut_3d,
-        write_dolby_vision_config,
     )
     lut_tools = True
 except ImportError:
@@ -28,9 +28,9 @@ __all__ = [
 if lut_tools:
     __all__.extend([
         "create_dolby_vision_config",
+        "generate_dolby_vision_config",
         "read_cal_file",
         "read_cube_file",
         "unity_lut_1d",
         "unity_lut_3d",
-        "write_dolby_vision_config",
     ])
